@@ -1,4 +1,4 @@
-""" B{PilotCompute Module}: Implementation of L{PilotComputeService}, L{PilotCompute}, L{ComputeUnit}.
+""" PilotCompute Module: Implementation of PilotComputeService, PilotCompute, ComputeUnit.
 """
 
 import sys
@@ -50,6 +50,10 @@ class PilotComputeService(PilotComputeService):
             Keyword arguments:
             pcs_id -- Don't create a new, but connect to an existing (optional)
         """
+
+        if  not coordination_url :
+            raise Exception ("No COORDINATION_URL specified - abort")
+
         self.pilot_computes=[]
         self.coordination_url=coordination_url
         self.coordination_queue=""
@@ -152,11 +156,11 @@ class PilotComputeService(PilotComputeService):
         gram_url = bj_dict["resource_url"]
         logger.debug("start bigjob at: " + gram_url)
         bj = bigjob(self.coordination_url)
-        ppn="1"
-        if ("processes_per_node" in bj_dict):
-            ppn=bj_dict["processes_per_node"]
+
+        if("processes_per_node" not in bj_dict or bj_dict["processes_per_node"] == 'None'):
+            ppn="1"
         else:
-            bj_dict["processes_per_node"]="1"
+            ppn=bj_dict["processes_per_node"]
 
         walltime = 3600
         if ("walltime" in bj_dict):
@@ -172,14 +176,14 @@ class PilotComputeService(PilotComputeService):
 
 
         bj.start_pilot_job(lrms_url = gram_url,
-                           number_nodes = bj_dict["number_of_processes"],
+                           number_nodes = int(bj_dict["number_of_processes"]),
                            queue = bj_dict["queue"],
                            project = bj_dict["project"],
                            working_directory = working_directory, 
                            walltime = walltime,
                            processes_per_node = ppn,
                            filetransfers = bj_filetransfer,
-			               spmd_variation = bj_dict["spmd_variation"],
+                           spmd_variation = bj_dict["spmd_variation"],
                            external_queue = self.coordination_queue,
                            pilot_compute_description = bj_dict["pilot_compute_description"]
                            )
@@ -325,7 +329,7 @@ class PilotCompute(PilotCompute):
             are ignored.
         """
         cu = ComputeUnit(compute_unit_description)
-        return self._submit_cu(cu, self.get_local_working_directory())
+        return self._submit_cu(cu)
     
     def __repr__(self):
         return str(self.__bigjob)
@@ -334,13 +338,13 @@ class PilotCompute(PilotCompute):
     ###########################################################################
     # Internal methods
         
-    def _submit_cu(self, compute_unit, parent_bj_workdir):
+    def _submit_cu(self, compute_unit):
         """ Submits compute unit to Bigjob """
         logger.debug("Submit CU to big-job")
         sj = subjob()
         sj.submit_job(self.__bigjob.pilot_url, compute_unit.subjob_description)
         self.__subjobs.append(sj)
-        compute_unit._update_subjob(sj, parent_bj_workdir)
+        compute_unit._update_subjob(sj)
 
         return compute_unit
         
@@ -437,12 +441,12 @@ class ComputeUnit(ComputeUnit):
         self.compute_unit_description = compute_unit_description # CU Description
         self.subjob_description = self.__translate_cu_sj_description(compute_unit_description)
 
-    def _update_subjob(self, subjob, parent_bj_workdir):
+    def _update_subjob(self, subjob):
         self.__subjob = subjob
 
         # at this point, we can also set the working directory for this CU
-        self._local_working_directory = "%s/%s" \
-            % (parent_bj_workdir, subjob.uuid)
+        #self._local_working_directory = "%s/%s" \
+        #    % (parent_bj_workdir, subjob.uuid)
         
     # INTERNAL
     def __translate_cu_sj_description(self, compute_unit_description):
